@@ -47,11 +47,11 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "17-May-24"
+#define SND_DATE "1-July-24"
 #ifndef SND_VERSION
-#define SND_VERSION "24.4"
+#define SND_VERSION "24.5"
 #endif
 #define SND_MAJOR_VERSION "24"
-#define SND_MINOR_VERSION "4"
+#define SND_MINOR_VERSION "5"
 
 #endif
