@@ -20,8 +20,8 @@
 (f1 tc-size)  ; safe_closure_a_o[checked] op_if_a_p
 
 (define (f2 x)
-  (unless (<= x 0) ; fx_leq_ti 
-    (f2 (- x 1)))) ; fx_subtract_t1 
+  (unless (<= x 0) ; fx_leq_ti
+    (f2 (- x 1)))) ; fx_subtract_t1
 
 (f2 tc-size)  ; safe_closure_a_o[checked] op_if_a_r
 
@@ -32,7 +32,7 @@
   (when (> x 0)                     ; fx_gt_ti
     (f11 (- x 1) (- y 2) (+ z 1)))) ; op_safe_closure_3a fx_add_v1 [subtract]
 
-(f11 tc-size 2 3) 
+(f11 tc-size 2 3)
 
 (define (f12 x y z)
   (unless (<= x 0)                  ; fx_leq_ti
@@ -41,7 +41,7 @@
 (f12 tc-size 1 2)
 
 ;;; --------------------------------------------------------------------------------
-;OP_TC_IF_A_Z_IF_A_Z_L3A and reverse
+;OP_TC_IF_A_Z_IF_A_Z_L3A and reverse [23-Jun-24]
 
 (define (f3 x y z)
   (if (<= x 0)                      ; fx_leq_ti
@@ -50,7 +50,8 @@
 	  x
 	  (f3 (- x 1) (- y 1) z)))) ; fx_subtract_t|u1 fx_v
 
-(f3 tc-size (* 2 tc-size) 0) ; safe_closure_3a[checked] if_a_a_p[leq] if_b_a_p[=] -- b_a_p leq case?
+(unless (= tc-size (f3 tc-size (* 2 tc-size) 0)) ; safe_closure_3a[checked] if_a_a_p[leq] if_b_a_p[=] -- b_a_p leq case?
+  (display "f3 if_a_z_if_a_z_l3a: ~S~%" (f3 tc-size (*2 tc-size) 0)))
 
 (define (f4 x y z)
   (if (<= x 0)
@@ -59,10 +60,11 @@
 	  (f4 (- x 1) (- y 1) z)
 	  x)))
 
-(f4 tc-size (* 2 tc-size) 0) ; safe_closure_3a[checked] if_a_a_p[leq] if_a_p_a[gt]
+(unless (= tc-size (f4 tc-size (* 2 tc-size) 0)) ; safe_closure_3a[checked] if_a_a_p[leq] if_a_p_a[gt]
+  (display "f4 if_a_z_if_a_l3a_z: ~S~%" (f4 tc-size (*2 tc-size) 0)))
 
 ;;; --------------------------------------------------------------------------------
-;OP_TC_IF_A_LA_IF_A_Z[_Z] -- already handled:
+;OP_TC_IF_A_LA_IF_A_Z[_Z] -- already handled
 
 (define (f5 x)        ; op_tc_if_a_la_z
   (if (>= x 0)        ; opt_b_ii_sc_geq_0
@@ -71,7 +73,7 @@
 	  x
 	  'oops!)))
 
-(f5 tc-size) 
+(f5 tc-size)
 
 ;;; --------------------------------------------------------------------------------
 ;OP_TC_AND_A_OR_A_L3A and OP_TC_OR_A_AND_A_L3A
@@ -91,7 +93,7 @@
 (f7 tc-size (* 2 tc-size) 0)
 
 ;;; --------------------------------------------------------------------------------
-;OP_TC_IF_A_Z_IF_A_Z_IF_A_Z_LA 
+;OP_TC_IF_A_Z_IF_A_Z_IF_A_Z_LA
 
 (define (f7 x)
   (if (= x 0)
@@ -105,7 +107,7 @@
 (f7 tc-size) ; op_safe_closure_3a[checked] if_a_a_p[fx_lt_si] if_b_a_p[fb_num_eq_s0]
 
 ;;; --------------------------------------------------------------------------------
-;OP_TC_COND_A_Z_L3A
+;OP_TC_COND_A_Z_L3A [24-June-24]
 
 (define (f8 x y z)
   (cond ((= x 0) 0)                     ; fx_num_eq_t0
@@ -136,7 +138,7 @@
 (f10 tc-size (/ tc-size 10) (/ tc-size 10))
 
 ;;; --------------------------------------------------------------------------------
-;OP_RECUR_IF_A_A_opLAA_LAAq OP_RECUR_IF_A_opLAA_LAAq_A 
+;OP_RECUR_IF_A_A_opLAA_LAAq OP_RECUR_IF_A_opLAA_LAAq_A
 
 (define (rc1 x y)
   (if (<= y 0)
@@ -194,7 +196,7 @@
 (trc2r)
 
 ;;; --------------------------------------------------------------------------------
-;;; OP_RECUR_IF_A_A_IF_A_A_opL3A_L3Aq?, 
+;;; OP_RECUR_IF_A_A_IF_A_A_opL3A_L3Aq?,
 
 ;OP_RECUR_OR_A_AND_A_opLA(AA)q?
 
@@ -225,40 +227,57 @@
 
 (tcase1)
 
+#|
 (define (case2 i) ; case_a_i_s_a, uses t_lookup
   (case i
     ((0) 0)
     ((1) 1)
     ((2) 2)
     (else 3)))
-
+|#
 (define (tcase2)
   (do ((i 0 (+ i 1)))
       ((= i case-size))
-    (case2 i)))
+    ;(case2 i)
+    (case i
+      ((0) 0)
+      ((1) 1)
+      ((2) 2)
+      (else 3))))
 
 (tcase2)
 
+#|
 (define (case3 x lst)        ; case_a_i_s_a
   (case x                    ;   t_lookup
     ((0) (pair? lst))        ; fx_is_pair_u
     ((1) (pair? (cdr lst)))  ; fx_is_pair_cdr_u
     (else (null? lst))))     ; fx_is_null_u
-
-(define (tcase3)
+|#
+(define (tcase3 lst)
   (do ((i 0 (+ i 1)))        ; op_simple_do_step -> safe_closure_aa_o
       ((= i case-size))
-    (case3 i '(1 2))))       ; fx_t fx_q
+    ;(case3 i '(1 2))       ; fx_t fx_q
+    (case i                    ;   t_lookup
+      ((0) (pair? lst))        ; fx_is_pair_u
+      ((1) (pair? (cdr lst)))  ; fx_is_pair_cdr_u
+      (else (null? lst)))))    ; fx_is_null_u
 
-(tcase3)
 
-(define (tcase3-1)
+(tcase3 '(1 2))
+
+(define (tcase3-1 lst)
   (do ((i 0 (+ i 1)))                ; op_simple_do_step -> safe_closure_aa_o, g_add_x1
       ((= i case-size))              ; g_num_eq_2
-    (case3 (remainder i 3) '(1 2)))) ; modulo_p_pi via fx_c_ti_direct(80400 check_do), fx_q
+    ;(case3 (remainder i 3) '(1 2)))) ; modulo_p_pi via fx_c_ti_direct(80400 check_do), fx_q
+    (case i                    ;   t_lookup
+      ((0) (pair? lst))        ; fx_is_pair_u
+      ((1) (pair? (cdr lst)))  ; fx_is_pair_cdr_u
+      (else (null? lst)))))    ; fx_is_null_u
 
-(tcase3-1)
+(tcase3-1 '(1 2))
 
+#|
 (define (case4 x) ; case a_e_s_a
   (case (remainder x 5)
     ((a) 0)
@@ -266,19 +285,26 @@
     ((c) 2)
     ((d) 3)
     (else 4)))
+|#
 
 (define (tcase4)
   (do ((i 0 (+ i 1)))
       ((= i case-size))
-    (case4 i)))
+    ;(case4 i)
+    (case (remainder i 5)
+      ((a) 0)
+      ((b) 1)
+      ((c) 2)
+      ((d) 3)
+      (else 4))))
 
 (tcase4)
 
-(define sym-selector
+(define-constant sym-selector  ; currently not handled by opt* (also int|any-selector, but they're fxable??)
   (let ((syms '(a b c d e)))
     (lambda (x)
       (syms (remainder x 5))))) ; list-ref is slower
-
+#|
 (define (case5 x) ; case p_e_s
   (case (sym-selector x)
     ((a) 0)
@@ -286,17 +312,23 @@
     ((c) 2)
     ((d) 3)
     (else 4)))
-
+|#
 (define (tcase5)
   (do ((i 0 (+ i 1)))
       ((= i case-size))
-    (case5 i)))
+    ;(case5 i)
+    (case (sym-selector i)
+      ((a) 0)
+      ((b) 1)
+      ((c) 2)
+      ((d) 3)
+      (else 4))))
 
 (tcase5)
 
-(define (int-selector x)
+(define-constant (int-selector x)
   (remainder x 5))
-
+#|
 (define (case6 x) ; case p_i_s
   (case (int-selector x)
     ((1) 0)
@@ -304,17 +336,23 @@
     ((3) 2)
     ((4) 3)
     (else 4)))
-
+|#
 (define (tcase6)
   (do ((i 0 (+ i 1)))
       ((= i case-size))
-    (case6 i)))
+    ;(case6 i)
+    (case (int-selector i)
+      ((1) 0)
+      ((2) 1)
+      ((3) 2)
+      ((4) 3)
+      (else 4))))
 
 (tcase6)
 
-(define (any-selector x)
+(define-constant (any-selector x)
   (if (zero? (remainder x 3)) #\a))
-
+#|
 (define (case7 x) ; case p_g_s
   (case (any-selector x)
     ((1/2) 0)
@@ -322,14 +360,21 @@
     ((#<unspecified>) 2)
     ((#f) 3)
     (else 4)))
-
+|#
 (define (tcase7)
   (do ((i 0 (+ i 1)))
       ((= i case-size))
-    (case7 i)))
+    ;(case7 i)
+    (case (any-selector i)
+      ((1/2) 0)
+      ((#\a) 1)
+      ((#<unspecified>) 2)
+      ((#f) 3)
+      (else 4))))
 
 (tcase7)
 
+#|
 (define (case8 x) ; case a_g_s_a
   (case (even? x)
     ((1/2) 0)
@@ -337,41 +382,62 @@
     ((#<unspecified>) 2)
     ((#f) 3)
     (else 4)))
+|#
 
 (define (tcase8)
   (do ((i 0 (+ i 1)))
       ((= i case-size))
-    (case8 i)))
+   ;(case8 i)
+    (case (even? i)
+      ((1/2) 0)
+      ((#\a) 1)
+      ((#<unspecified>) 2)
+      ((#f) 3)
+      (else 4))))
 
 (tcase8)
 
+#|
 (define (case9 x) ; case a_e_g
   (case (even? x)
     ((#t) (display x #f) (not x))
     ((#f) (write x #f) (integer? x))
     (else 'oops)))
+|#
 
 (define (tcase9)
   (do ((i 0 (+ i 1)))
       ((= i case-size))
-    (case9 i)))
+    ;(case9 i)
+    (case (even? i)
+      ((#t) (display i #f) (not i))
+      ((#f) (write i #f) (integer? i))
+      (else 'oops))))
 
 (tcase9)
 
+#|
 (define (case10 x) ; case a_g_g
   (case (even? x)
     ((#t) (display x #f) (not x))
     ((1/2) (write x #f) (integer? x))
     ((1 2 3) 0)
     (else 'oops)))
+|#
 
 (define (tcase10)
   (do ((i 0 (+ i 1)))
       ((= i case-size))
-    (case10 i)))
+    ;(case10 i)
+    (case (even? i)
+      ((#t) (display i #f) (not i))
+      ((1/2) (write i #f) (integer? i))
+      ((1 2 3) 0)
+      (else 'oops))))
 
 (tcase10)
 
+#|
 (define (case11 x) ; case a_s_g
   (case (remainder x 5)
     ((a) 0)
@@ -379,28 +445,43 @@
     ((c) (+ 1 2))
     ((d) 3)
     (else 4)))
+|#
 
 (define (tcase11)
   (do ((i 0 (+ i 1)))
       ((= i case-size))
-    (case11 i)))
+    ;(case11 i)
+    (case (remainder i 5)
+      ((a) 0)
+      ((b) (display i #f) 1)
+      ((c) (+ 1 2))
+      ((d) 3)
+      (else 4))))
 
 (tcase11)
 
+#|
 (define (case12 x) ; case p_g_g
   (case (any-selector x)
     ((#t) (display x #f) (not x))
     ((1/2) (write x #f) (integer? x))
     ((1 2 3) 0)
     (else 'oops)))
+|#
 
 (define (tcase12)
   (do ((i 0 (+ i 1)))
       ((= i case-size))
-    (case12 i)))
+    ;(case12 i)
+    (case (any-selector i)
+      ((#t) (display i #f) (not i))
+      ((1/2) (write i #f) (integer? i))
+      ((1 2 3) 0)
+      (else 'oops))))
 
 (tcase12)
 
+#|
 (define (case13 x) ; case p_e_g
   (case (sym-selector x)
     ((a) 0)
@@ -408,14 +489,22 @@
     ((c) 2)
     ((d) 3)
     (else 4)))
+|#
 
 (define (tcase13)
   (do ((i 0 (+ i 1)))
       ((= i case-size))
-    (case13 i)))
+    ;(case13 i)
+    (case (sym-selector i)
+      ((a) 0)
+      ((b) (display i #f) 32)
+      ((c) 2)
+      ((d) 3)
+      (else 4))))
 
 (tcase13)
 
+#|
 (define (case14 x) ; a_g_s
   (case x
     ((1 2 3) 0)
@@ -423,28 +512,43 @@
     ((6) 2)
     ((7 8 9) 3)
     ((10) 4)))
+|#
 
 (define (tcase14)
   (do ((i 0 (+ i 1)))
       ((= i case-size))
-    (case14 i)))
+    ;(case14 i)
+    (case i
+      ((1 2 3) 0)
+      ((4 5) 1)
+      ((6) 2)
+      ((7 8 9) 3)
+      ((10) 4))))
 
 (tcase14)
 
+#|
 (define (case15 x) ; case a_e_s
   (case (remainder x 5)
     ((a) 0)
     ((b) 1)
     ((c) 2)
     ((d) 3)))
+|#
 
 (define (tcase15)
   (do ((i 0 (+ i 1)))
       ((= i case-size))
-    (case15 i)))
+    ;(case15 i)
+    (case (remainder i 5)
+      ((a) 0)
+      ((b) 1)
+      ((c) 2)
+      ((d) 3))))
 
 (tcase15)
 
+#|
 (define (case16 x) ; case a_s_g_a
   (case (remainder x 5)
     ((a) 0)
@@ -452,11 +556,18 @@
     ((c) (+ 1 2))
     ((d) 3)
     (else 4)))
+|#
 
 (define (tcase16)
   (do ((i 0 (+ i 1)))
       ((= i case-size))
-    (case16 i)))
+    ;(case16 i)
+    (case (remainder i 5)
+      ((a) 0)
+      ((b) (display i #f) 1)
+      ((c) (+ 1 2))
+      ((d) 3)
+      (else 4))))
 
 (tcase16)
 
