@@ -228,76 +228,6 @@
 (wtest)
 
 
-;;; -------- multiple values --------
-(define (mv1)
-  (+ (values 1 2 3)))
-(define (mv2)
-  (+ 1 (values 2 3)))
-(define (mv3)
-  (+ (values 1 2) 3))
-(define (mv4 x)
-  (+ x (values x x)))
-(define (mv5 x)
-  (+ (values x x) x))
-(define (mv-clo1 x y)
-  (+ x y))
-(define (mv6 x)
-  (mv-clo1 (values x 1)))
-(define (mv-clo2 . args)
-  (apply + args))
-(define (mv7 x)
-  (mv-clo2 (values x 1)))
-(define (mv8)
-  (+ (values 1 2 3) (values 3 -2 -1)))
-(define (mv9)
-  (+ 1 (values 2 3 4) -4))
-(define (mv10)
-  (+ (values 1 2 3)))
-(define (mv11)
-  (+ 1 (values -1 2 4)))
-(define (mv12 x y)
-  (+ x y (values 2 3 4)))
-
-;;; pair_sym: (mv-clo (values x 1)), h_c_aa: (values x 1), splice_eval_args2 ([i] 1), eval_arg2->apply mv-clo! (loop below is safe_dotimes_step_p
-;;;   not enough args for mv-clo1? 
-;;; mv-clo2: closure_s_p -> pair_sym ->h_c_aa etc as above!
-;;;   perhaps apply_[safe_]closure?
-
-(define (mvtest)
-  (unless (= (mv1) 6) (format *stderr* "mv1: ~S~%" (mv1)))
-  (unless (= (mv2) 6) (format *stderr* "mv2: ~S~%" (mv2)))
-  (unless (= (mv3) 6) (format *stderr* "mv3: ~S~%" (mv3)))
-  (unless (= (mv4 2) 6) (format *stderr* "(mv4 2): ~S~%" (mv4 2)))
-  (unless (= (mv5 2) 6) (format *stderr* "(mv5 2): ~S~%" (mv5 2)))
-  (unless (= (mv6 5) 6) (format *stderr* "(mv6 5): ~S~%" (mv6 5)))
-  (unless (= (mv7 5) 6) (format *stderr* "(mv7 5): ~S~%" (mv7 5)))
-  (unless (= (mv8) 6) (format *stderr* "mv8: ~S~%" (mv8)))
-  (unless (= (mv9) 6) (format *stderr* "mv9: ~S~%" (mv9)))
-  (unless (= (mv10) 6) (format *stderr* "mv10: ~S~%" (mv10)))
-  (unless (= (mv11) 6) (format *stderr* "mv11: ~S~%" (mv11)))
-  (unless (= (mv12 -1 -2) 6) (format *stderr* "(mv12 -1 -2): ~S~%" (mv12 -1 -2)))
-  (do ((i 0 (+ i 1)))
-      ((= i 50000))
-    (mv1)
-    (mv2)
-    (mv3)
-    (mv4 i)
-    (mv5 i)
-    (mv6 i)
-    (mv7 i)
-    (mv8)
-    (mv9)
-    (mv10)
-    (mv11)
-    (mv12 -2 -1)
-    ))
-
-(mvtest)
-
-(when (> (*s7* 'profile) 0)
-  (show-profile 200))
-
-
 ;;; -------- typers --------
 (let ()
   (define (10-or-12? val)
